@@ -44,10 +44,6 @@ trellis.par.set(ps)
 #  library(mcglm)
 #  packageVersion("mcglm")
 
-## ---- echo=FALSE, error=FALSE, message=FALSE, warning=FALSE-------
-library(mcglm)
-packageVersion("mcglm")
-
 ## ---- warning = FALSE, message = FALSE----------------------------
 ## Dobson (1990) Page 93: Randomized Controlled Trial :
 counts <- c(18,17,15,20,10,20,25,13,12)
@@ -56,14 +52,15 @@ treatment <- gl(3,3)
 print(d.AD <- data.frame(treatment, outcome, counts))
 
 ## ---- warning = FALSE, message = FALSE----------------------------
-fit.glm <- glm(counts ~ outcome + treatment, family = poisson)
+fit.glm <- glm(counts ~ outcome + treatment, family = quasipoisson)
 
 ## ---- warning = FALSE, message = FALSE----------------------------
+require(mcglm)
 require(Matrix)
 # Matrix linear predictor
-Z0 <- Diagonal(dim(d.AD)[1],1)
+Z0 <- mc_id(d.AD)
 fit.qglm <- mcglm(linear_pred = c(counts ~ outcome + treatment),
-                  matrix_pred = list("resp1" = list(Z0)),
+                  matrix_pred = list("resp1" = Z0),
                   link = "log", variance = "tweedie", data = d.AD,
                   control_algorithm = list(verbose = FALSE,
                                            method = "chaser",
@@ -73,6 +70,9 @@ fit.qglm <- mcglm(linear_pred = c(counts ~ outcome + treatment),
 cbind("GLM" = coef(fit.glm),
       "McGLM" = coef(fit.qglm, type = "beta")$Estimates)
 
+cbind("GLM" = sqrt(diag(vcov(fit.glm))), 
+      "McGLM" = coef(fit.qglm, type = "beta", std.error = TRUE)$Std.error)
+
 ## ---- warning = FALSE, message = FALSE----------------------------
 # Loading the data set
 utils::data(anorexia, package = "MASS")
@@ -82,13 +82,12 @@ anorex.1 <- glm(Postwt ~ Prewt + Treat + offset(Prewt),
                family = gaussian, data = anorexia)
 
 # McGLM fit
-Z0 <- Diagonal(dim(anorexia)[1],1)
+Z0 <- mc_id(anorexia)
 fit.anorexia <- mcglm(linear_pred = c(Postwt ~ Prewt + Treat),
-                      matrix_pred = list(list(Z0)),
-                      link = "identity", variance = "constant",
+                      matrix_pred = list(Z0),
                       offset = list(anorexia$Prewt),
                       power_fixed = TRUE, data = anorexia,
-                      control_algorithm = list("correct" = FALSE))
+                      control_algorithm = list("correct" = TRUE))
 
 ## ---- warning = FALSE, message = FALSE----------------------------
 # Estimates
@@ -119,9 +118,9 @@ list_initial$tau <- list(summary(fit.lot1)$dispersion)
 list_initial$rho = 0
 
 ## ---- warning = FALSE, message = FALSE----------------------------
-Z0 <- Diagonal(dim(clotting)[1], 1)
+Z0 <- mc_id(clotting)
 fit.lot1.mcglm <- mcglm(linear_pred = c(lot1 ~ log(u)),
-                        matrix_pred = list(list(Z0)),
+                        matrix_pred = list(Z0),
                         link = "inverse", variance = "tweedie",
                         data = clotting,
                         control_initial = list_initial)
@@ -140,7 +139,7 @@ list_initial$tau <- list("resp1" = c(var(1/clotting$lot2)))
 
 ## ---- warning = FALSE, message = FALSE----------------------------
 fit.lot2.mcglm <- mcglm(linear_pred = c(lot2 ~ log(u)),
-                        matrix_pred = list(list(Z0)),
+                        matrix_pred = list(Z0),
                         link = "inverse", variance = "tweedie",
                         data = clotting,
                         control_initial = list_initial)
@@ -162,19 +161,19 @@ list_initial$tau <- list(c(0.00149), c(0.001276))
 list_initial$rho = 0.80
 
 # Matrix linear predictor
-Z0 <- Diagonal(dim(clotting)[1],1)
+Z0 <- mc_id(clotting)
 
 # Fit bivariate Gamma model
 fit.joint.mcglm <- mcglm(linear_pred = c(lot1 ~ log(u), lot2 ~ log(u)),
-                         matrix_pred = list(list(Z0), list(Z0)),
+                         matrix_pred = list(Z0, Z0),
                          link = c("inverse", "inverse"),
                          variance = c("tweedie", "tweedie"),
                          data = clotting,
                          control_initial = list_initial,
                          control_algorithm = list("correct" = TRUE,
-                                                 "method" = "rc",
-                                                 "tuning" = 0.001,
-                                                 "max_iter" = 100))
+                                                 "method" = "chaser",
+                                                 "tuning" = 0.1,
+                                                 "max_iter" = 1000))
 summary(fit.joint.mcglm)
 
 ## ---- warning = FALSE, message = FALSE----------------------------
@@ -188,7 +187,7 @@ list_initial$rho = 0
 
 # Fit bivariate Gamma model
 fit.joint.log <- mcglm(linear_pred = c(lot1 ~ log(u), lot2 ~ log(u)),
-                       matrix_pred = list(list(Z0),list(Z0)),
+                       matrix_pred = list(Z0,Z0),
                        link = c("log", "log"),
                        variance = c("tweedie", "tweedie"),
                        data = clotting,
@@ -208,9 +207,9 @@ glm.out = glm(cbind(Menarche, Total-Menarche) ~ Age,
 
 ## ---- warning = FALSE, message = FALSE----------------------------
 # Matrix linear predictor
-Z0 <- Diagonal(dim(data)[1],1)
+Z0 <- mc_id(data)
 fit.logit <- mcglm(linear_pred = c(resp ~ Age),
-                   matrix_pred = list(list(Z0)),
+                   matrix_pred = list(Z0),
                    link = "logit", variance = "binomialP",
                    Ntrial = list(data$Ntrial), data = data)
 
@@ -224,7 +223,7 @@ cbind("GLM" = c(sqrt(diag(vcov(glm.out))),NA),
 
 ## ---- warning = FALSE, message = FALSE----------------------------
 fit.logit.power <- mcglm(linear_pred = c(resp ~ Age),
-                         matrix_pred = list(list(Z0)),
+                         matrix_pred = list(Z0),
                          link = "logit", variance = "binomialP",
                          Ntrial = list(data$Ntrial),
                          power_fixed = FALSE, data = data)
