@@ -8,34 +8,6 @@ opts_chunk$set(
 
 options(width=68)
 
-##----------------------------------------------------------------------
-
-library(latticeExtra)
-rm(list=ls())
-
-## Color palette.
-mycol <- c("#E41A1C", "#377EB8", "#4DAF4A", "#984EA3", "#FF7F00",
-           "#FFFF33")
-dput(mycol)
-
-## Trellis graphical style.
-ps <- list(
-    box.rectangle=list(col=1, fill=c("gray70")),
-    box.umbrella=list(col=1, lty=1),
-    dot.symbol=list(col=1, pch=19),
-    dot.line=list(col="gray50", lty=3),
-    plot.symbol=list(col=1, cex=0.8),
-    plot.line=list(col=1),
-    plot.polygon=list(col="gray95"),
-    superpose.line=list(col=mycol, lty=1),
-    superpose.symbol=list(col=mycol, pch=1),
-    superpose.polygon=list(col=mycol),
-    strip.background=list(col=c("gray80","gray50"))
-    )
-trellis.par.set(ps)
-## show.settings()
-
-
 ## ---- eval=FALSE--------------------------------------------------
 #  library(devtools)
 #  install_git("wbonat/mcglm")
@@ -44,10 +16,6 @@ trellis.par.set(ps)
 #  library(mcglm)
 #  packageVersion("mcglm")
 
-## ---- echo=FALSE, error=FALSE, message=FALSE, warning=FALSE-------
-library(mcglm)
-packageVersion("mcglm")
-
 ## ---- warning = FALSE, message = FALSE----------------------------
 # Loading extra packages
 require(mcglm)
@@ -59,22 +27,22 @@ require(tweedie)
 set.seed(2503)
 
 # Fixed component
-covariate <- seq(-1,1, l = 100)
-X <- model.matrix(~ covariate)
+x1 <- seq(-1,1, l = 100)
+X <- model.matrix(~ x1)
 mu1 <- mcglm::mc_link_function(beta = c(1,0.8), X = X, offset = NULL, 
                         link = "identity")
 # Random component
 y1 <- rnorm(100, mu1$mu, sd = 0.5)
 
-# Matrix linear predictor
-Z0 <- Diagonal(100, 1)
+# Data structure
+data <- data.frame("y1" = y1, "x1" = x1)
 
-# Data set
-data <- data.frame("y1" = y1, "covariate" = covariate)
+# Matrix linear predictor
+Z0 <- mc_id(data)
 
 # Fit
-fit1.id <- mcglm(linear_pred = c(y1 ~ covariate), 
-                 matrix_pred = list(list(Z0)),
+fit1.id <- mcglm(linear_pred = c(y1 ~ x1), 
+                 matrix_pred = list(Z0),
                  data = data)
 
 
@@ -86,15 +54,15 @@ summary(fit1.id)
 
 ## -----------------------------------------------------------------
 # Fit using inverse covariance link function 
-fit1.inv <- mcglm(linear_pred = c(y1 ~ covariate), 
-                  matrix_pred = list(list(Z0)),
+fit1.inv <- mcglm(linear_pred = c(y1 ~ x1), 
+                  matrix_pred = list(Z0),
                   covariance = "inverse", data = data)
 
 
 ## ---- message=FALSE, warning=FALSE--------------------------------
 # Fit using expm covariance link function
-fit1.expm <- mcglm(linear_pred = c(y1 ~ covariate), 
-                   matrix_pred = list(list(Z0)),
+fit1.expm <- mcglm(linear_pred = c(y1 ~ x1), 
+                   matrix_pred = list(Z0),
                    covariance = "expm", data = data)
 
 ## -----------------------------------------------------------------
@@ -110,127 +78,130 @@ c(coef(fit1.id)$Estimates[3],
 
 ## -----------------------------------------------------------------
 # Mean model
-covariate <- seq(-1,1, l = 100)
-X <- model.matrix(~ covariate)
+set.seed(1811)
+x1 <- seq(-1,1, l = 100)
+X <- model.matrix(~ x1)
 mu1 <- mcglm::mc_link_function(beta = c(1,0.8), X = X, offset = NULL, 
                         link = "identity")
+z1 <- rnorm(100, mean = 0, sd = 0.25)
+data <- data.frame("id" = 1, "x1" = x1, "z1" = z1)
 
 # Matrix linear predictor
-Z0 <- Diagonal(100, 1)
-Z1 <- Diagonal(100, c(rep(0,50),rep(1,50)))
+Z <- mc_dglm(~ z1, id = 'id', data = data)
 
 # Covariance model
-Sigma <- mcglm::mc_matrix_linear_predictor(tau = c(0.2, 0.15), 
-                                           Z = list(Z0,Z1))
-y1 <- rnorm(100, mu1$mu, sd = sqrt(diag(Sigma)))
-data <- data.frame("y1" = y1, "covariate" = covariate)
+Sigma <- mcglm::mc_matrix_linear_predictor(tau = c(0.2, 0.15), Z = Z)
 
-fit2.id <- mcglm(linear_pred = c(y1 ~ covariate), 
-                 matrix_pred = list(list(Z0,Z1)), 
-                 data = data)
+# Simulating the response variable
+y1 <- rnorm(100, mu1$mu, sd = sqrt(diag(Sigma)))
+data$y <- y1
+
+# Fitting
+fit2.id <- mcglm(linear_pred = c(y1 ~ x1), matrix_pred = list(Z), data = data)
 
 ## -----------------------------------------------------------------
 # Mean model
-covariate <- seq(-1,1, l = 200)
-X <- model.matrix(~ covariate)
+x1 <- seq(-1,1, l = 100)
+X <- model.matrix(~ x1)
 mu1 <- mcglm::mc_link_function(beta = c(1,0.8), X = X, offset = NULL, 
                         link = "identity")
-# Covariance model
-Z0 <- Diagonal(200, 1)
-Z1.temp <- Matrix(rep(1,10)%*%t(rep(1,10)))
-Z1.list <- list()
-for(i in 1:20){Z1.list[[i]] <- Z1.temp}
-Z1 <- bdiag(Z1.list)
-Sigma <- mcglm::mc_matrix_linear_predictor(tau = c(0.2, 0.15), Z = list(Z0,Z1))
 
-# Response variable
+# Data structure
+data <- data.frame("id" = as.factor(rep(1:10, each = 10)), "x1" = x1)
+
+# Covariance model
+Z0 <- mc_id(data)
+Z1 <- mc_mixed(~ 0 + id, data = data)
+Sigma <- mcglm::mc_matrix_linear_predictor(tau = c(0.2, 0.15), Z = c(Z0,Z1))
+
+# Simulating the Response variable
 y1 <- as.numeric(rmvnorm(1, mean = mu1$mu, sigma = as.matrix(Sigma)))
-data <- data.frame("y1" = y1, "covariate" = covariate)
+data <- data.frame("y1" = y1, "x1" = x1)
 
 # Fit
-fit3.id <- mcglm(linear_pred = c(y1 ~ covariate), 
-                 matrix_pred = list("resp1" = list(Z0,Z1)), data = data)
+fit3.id <- mcglm(linear_pred = c(y1 ~ x1), 
+                 matrix_pred = list("resp1" = c(Z0,Z1)), data = data)
 
 ## -----------------------------------------------------------------
 summary(fit3.id)
 
 ## -----------------------------------------------------------------
 # Mean model
-covariate <- seq(-1,1, l = 250)
-X <- model.matrix(~ covariate)
-mu1 <- mcglm::mc_link_function(beta = c(1,0.8), X = X, offset = NULL, 
-                        link = "logit")
+x1 <- seq(-1,1, l = 500)
+X <- model.matrix(~ x1)
+mu1 <- mcglm::mc_link_function(beta = c(1,0.8), X = X, offset = NULL, link = "logit")
+
+# Data structure
+data <- data.frame("x1" = x1)
+
 # Covariance model
-Z0 <- Diagonal(500, 1)
+Z0 <- mc_id(data)
 
-# Response variable
+# Simulating the response variable
 set.seed(123)
-y1 <- rbinom(500, prob = mu1$mu, size = 10)/10
-
-# Data set
-data <- data.frame("y1" = y1, "covariate" = covariate)
+data$y <- rbinom(500, prob = mu1$mu, size = 10)/10
 
 ## -----------------------------------------------------------------
 # Fit
-fit4.logit <- mcglm(linear_pred = c(y1 ~ covariate), 
-                    matrix_pred = list(list(Z0)),
+fit4.logit <- mcglm(linear_pred = c(y ~ x1), 
+                    matrix_pred = list(Z0),
                     link = "logit", variance = "binomialP",
                     power_fixed = TRUE,
-                    Ntrial = list(rep(10,250)), data = data)
+                    Ntrial = list(rep(10,500)), data = data)
 
 ## -----------------------------------------------------------------
-fit4.cauchit <- mcglm(linear_pred = c(y1 ~ covariate), 
-                      matrix_pred = list(list(Z0)),
+fit4.cauchit <- mcglm(linear_pred = c(y ~ x1), 
+                      matrix_pred = list(Z0),
                       link = "cauchit", variance = "binomialP", 
                       Ntrial = list(rep(10,250)), data = data)
 
 ## -----------------------------------------------------------------
-fit4.logitP <- mcglm(linear_pred = c(y1 ~ covariate), 
-                      matrix_pred = list(list(Z0)),
+fit4.logitP <- mcglm(linear_pred = c(y ~ x1), 
+                      matrix_pred = list(Z0),
                       link = "logit", variance = "binomialP",
                       power_fixed = FALSE,
-                      Ntrial = list(rep(10,250)), data = data)
+                      Ntrial = list(rep(10,500)), data = data)
 
 ## -----------------------------------------------------------------
-fit4.logitPQ <- mcglm(linear_pred = c(y1 ~ covariate), 
-                      matrix_pred = list(list(Z0)),
+fit4.logitPQ <- mcglm(linear_pred = c(y ~ x1), 
+                      matrix_pred = list(Z0),
                       link = "logit", variance = "binomialPQ",
                       power_fixed = FALSE,
-                      Ntrial = list(rep(10,250)), 
-                      control_algorithm = list(tuning = 0.5),
+                      Ntrial = list(rep(10,500)), 
+                      control_algorithm = list(tuning = 0.5, max_iter = 100),
                       data = data)
 
 ## -----------------------------------------------------------------
 # Mean model
-covariate <- seq(-2,2, l = 200)
-X <- model.matrix(~ covariate)
-mu <- mcglm::mc_link_function(beta = c(1,0.8), X = X, offset = NULL, 
-                        link = "log")
+
+x1 <- seq(-2,2, l = 200)
+X <- model.matrix(~ x1)
+mu <- mcglm::mc_link_function(beta = c(1,0.8), X = X, offset = NULL, link = "log")
+
+# Data structure
+data <- data.frame("x1" = x1)
 
 # Covariance model
-Z0 <- Diagonal(200, 1)
+Z0 <- mc_id(data)
 
-# Data
-y1 <- rpois(200, lambda = mu$mu)
-data <- data.frame("y1" = y1, "covariate" = covariate)
+# Data structure
+data$y <- rpois(200, lambda = mu$mu)
 
 # Fit
-fit.poisson <- mcglm(linear_pred = c(y1 ~ covariate), 
-                    matrix_pred = list(list(Z0)),
+fit.poisson <- mcglm(linear_pred = c(y ~ x1), 
+                    matrix_pred = list(Z0),
                     link = "log", variance = "tweedie",
                     power_fixed = TRUE, data = data)
 
 ## -----------------------------------------------------------------
 # Simulating negative binomial models
-require(tweedie)
 set.seed(1811)
-y1 <- rtweedie(200, mu = mu$mu, power = 2, phi = 0.5)
-y <- rpois(200, lambda = y1)
-data <- data.frame("y1" = y, "covariate" = covariate)
+x <- rtweedie(200, mu = mu$mu, power = 2, phi = 0.5)
+y <- rpois(200, lambda = x)
+data <- data.frame("y1" = y, "x1" = x1)
 
-fit.pt <- mcglm(linear_pred = c(y ~ covariate), 
-               matrix_pred = list(list(Z0)),
-               link = "log", variance = "poisson_tweedie", 
-               power_fixed = FALSE, data = data)
+fit.pt <- mcglm(linear_pred = c(y ~ x1), matrix_pred = list(Z0), 
+                link = "log", variance = "poisson_tweedie", 
+                power_fixed = FALSE, data = data)
 summary(fit.pt)
 
